0.9.9 API documentation: scalar_common.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Functions
scalar_common.hpp File Reference

GLM_EXT_scalar_common More...

Go to the source code of this file.

## Functions
template<typename T >
GLM_FUNC_DECL T | fmax (T a, T b)
| Returns the maximum component-wise values of 2 inputs. More...
template<typename T >
GLM_FUNC_DECL T | fmax (T a, T b, T C)
| Returns the maximum component-wise values of 3 inputs. More...
template<typename T >
GLM_FUNC_DECL T | fmax (T a, T b, T C, T D)
| Returns the maximum component-wise values of 4 inputs. More...
template<typename T >
GLM_FUNC_DECL T | fmin (T a, T b)
| Returns the minimum component-wise values of 2 inputs. More...
template<typename T >
GLM_FUNC_DECL T | fmin (T a, T b, T c)
| Returns the minimum component-wise values of 3 inputs. More...
template<typename T >
GLM_FUNC_DECL T | fmin (T a, T b, T c, T d)
| Returns the minimum component-wise values of 4 inputs. More...
template<typename T >
GLM_FUNC_DECL T | max (T a, T b, T c)
| Returns the maximum component-wise values of 3 inputs. More...
template<typename T >
GLM_FUNC_DECL T | max (T a, T b, T c, T d)
| Returns the maximum component-wise values of 4 inputs. More...
template<typename T >
GLM_FUNC_DECL T | min (T a, T b, T c)
| Returns the minimum component-wise values of 3 inputs. More...
template<typename T >
GLM_FUNC_DECL T | min (T a, T b, T c, T d)
| Returns the minimum component-wise values of 4 inputs. More...

## Detailed Description

GLM_EXT_scalar_common

Definition in file scalar_common.hpp.